@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2021-04-14
+# Release 2021-07-01
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.5.0
+MAKERESOLVEDEB_VERSION=1.5.1
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -240,7 +240,7 @@ process16() {
     create_directory ${DEB_DIR}/usr/lib
     extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
 
-    # Create symlinks
+    # BlackmagicRawAPI fixes
     create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
     link_object ../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
     link_object ../../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
@@ -333,10 +333,13 @@ process17() {
     extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
     extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libFairlightPanelAPI.so
 
-    # Create symlinks
-    create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
-    link_object ../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
-    link_object ../../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
+    # BlackmagicRawAPI fixes for 17.0 & 17.1
+    if [[ "$RESOLVE_VERSION" == 17.0* ]] || [[ "$RESOLVE_VERSION" == 17.1* ]];
+    then
+	create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
+	link_object ../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
+	link_object ../../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
+    fi
 
     # Create common data dir
     create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
